==> nextcloud-29.0.2.zip: nextcloud/lib/l10n/lv.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Nevar rakstīt \"config\" mapē!",
    "See %s" : "Skatīt %s",
    "Sample configuration detected" : "Atrasta konfigurācijas paraugs",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Konstatēts, ka paraug konfigurācija ir nokopēta. Tas var izjaukt jūsu instalāciju un nav atbalstīts. Lūdzu, izlasiet dokumentāciju, pirms veicat izmaiņas config.php",
    "%s email verification" : "%s e-pasta pārbaude",
    "Email verification" : "E-pasta pārbaude",
    "Click the following button to confirm your email." : "Noklikšķiniet uz šīs pogas, lai apstiprinātu savu e-pastu.",
    "Confirm your email" : "Apstipriniet savu e-pastu",
    "%1$s and %2$s" : "%1$s un %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s un %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s un %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s un %5$s",
    "PHP %s or higher is required." : "Ir nepieciešams PHP %s vai jaunāks.",
    "PHP with a version lower than %s is required." : "Ir nepieciešams PHP vecāks kā %s.",
    "%sbit or higher PHP required." : "Nepieciešams %sbit vai jaunāks PHP.",
    "The command line tool %s could not be found" : "Komandrindas rīku %s nevarēja atrast",
    "The library %s is not available." : "Bibliotēka %s nav pieejama.",
    "Server version %s or higher is required." : "Ir vajadzīga servera versija %s vai jaunāka.",
    "Server version %s or lower is required." : "Ir vajadzīga servera versija %s vai vecāka.",
    "Authentication" : "Autentifikācija",
    "Unknown filetype" : "Nezināms datnes veids",
    "Invalid image" : "Nederīgs attēls",
    "Avatar image is not square" : "Avatar attēls nav kvadrāts",
    "Files" : "Datnes",
    "View profile" : "Skatīt profilu",
    "today" : "šodien",
    "yesterday" : "vakar",
    "_%n day ago_::_%n days ago_" : ["%n dienas atpakaļ","%n dienas atpakaļ","%n dienām"],
    "last month" : "pagājušajā mēnesī",
    "_%n month ago_::_%n months ago_" : ["%n mēneši atpakaļ","%n mēneši atpakaļ","%n mēnešiem"],
    "last year" : "gājušajā gadā",
    "_%n year ago_::_%n years ago_" : ["%n gadiem","%n gadiem","%n gadiem"],
    "_%n hour ago_::_%n hours ago_" : ["%n stundas atpakaļ","%n stundas atpakaļ","%n stundām"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minūtes atpakaļ","%n minūtes atpakaļ","%n minūtēm"],
    "seconds ago" : "sekundēm",
    "File already exists" : "Datne jau pastāv",
    "File name is a reserved word" : "Datnes nosaukums ir aizņemts vārds",
    "File name is too long" : "Datnes nosaukums ir pārāk garš",
    "Empty filename is not allowed" : "Tukšs datnes nosaukums nav atļauts",
    "__language_name__" : "Latviešu",
    "Help & privacy" : "Palīdzība un privātums",
    "Appearance and accessibility" : "Izskats un piekļūstamība",
    "Apps" : "Lietotnes",
    "Personal settings" : "Personiskie iestatījumi",
    "Administration settings" : "Administrēšanas iestatījumi",
    "Settings" : "Iestatījumi",
    "Log out" : "Izrakstīties",
    "Email" : "E-pasts",
    "Phone" : "Tālrunis",
    "Twitter" : "Twitter",
    "Website" : "Mājaslapa",
    "Address" : "Adrese",
    "Profile picture" : "Profila attēls",
    "About" : "Par",
    "Additional settings" : "Papildu iestatījumi",
    "Oracle connection could not be established" : "Nevar izveidot savienojumu ar Oracle",
    "Set an admin password." : "Iestatiet administratora paroli.",
    "Open »%s«" : "Atvērt »%s«",
    "You are not allowed to share %s" : "Tev nav ļauts dalīties ar %s",
    "Could not find category \"%s\"" : "Nevarēja atrast kategoriju “%s”",
    "Sunday" : "Svētdiena",
    "Monday" : "Pirmdiena",
    "Tuesday" : "Otrdiena",
    "Wednesday" : "Trešdiena",
    "Thursday" : "Ceturtdiena",
    "Friday" : "Piektdiena",
    "Saturday" : "Sestdiena",
    "Sun." : "Sv.",
    "Mon." : "Pr.",
    "Tue." : "Ot.",
    "Wed." : "Tr.",
    "Thu." : "Ce.",
    "Fri." : "Pk.",
    "Sat." : "Se.",
    "Su" : "Sv",
    "Mo" : "Pr",
    "Tu" : "Ot",
    "We" : "Tr",
    "Th" : "Ce",
    "Fr" : "Pi",
    "Sa" : "Se",
    "January" : "Janvāris",
    "February" : "Februāris",
    "March" : "Marts",
    "April" : "Aprīlis",
    "May" : "Maijs",
    "June" : "Jūnijs",
    "July" : "Jūlijs",
    "August" : "Augusts",
    "September" : "Septembris",
    "October" : "Oktobris",
    "November" : "Novembris",
    "December" : "Decembris",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Mai.",
    "Jun." : "Jūn.",
    "Jul." : "Jūl.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dec.",
    "A valid password must be provided" : "Jānorāda derīga parole",
    "Login canceled by app" : "Pieteikšanos atcelā lietotne",
    "a safe home for all your data" : "droša vieta visiem Taviem datiem",
    "File is currently busy, please try again later" : "Datne pašlaik ir aizņemta. Lūdzu, vēlāk mēģiniet vēlreiz",
    "Application is not enabled" : "Lietotne nav iespējota",
    "Authentication error" : "Autentifikācijas kļūda",
    "Token expired. Please reload page." : "Pilnvarai ir beidzies termiņš. Lūdzu, pārlādējiet lapu.",
    "PHP module %s not installed." : "PHP modulis %s nav instalēts.",
    "Please ask your server administrator to install the module." : "Lūdzu, palūdziet savam servera administratoram, lai instalē moduli.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Tas ir iespējams, kešatmiņa / paātrinātājs, piemēram, Zend OPcache vai eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP modulis ir uzstādīts, taču tas joprojām ir uzskatāms kā trūkstošs, pazudis?",
    "Please ask your server administrator to restart the web server." : "Lūdzu, palūdziet savam servera administratoram, restartēt Web serveri.",
    "Storage unauthorized. %s" : "Krātuve neautorizēta. %s",
    "Storage incomplete configuration. %s" : "Storage incomplete configuration. %s",
    "Storage connection error. %s" : "Datu savienojuma kļūda. %s",
    "Storage is temporarily not available" : "Glabātuve īslaicīgi nav pieejama",
    "Storage connection timeout. %s" : "Datu savienojuma taimauts. %s",
    "Summary" : "Kopsavilkums",
    "404" : "404",
    "Help" : "Palīdzība",
    "Users" : "Lietotāji",
    "Unknown user" : "Nezināms lietotājs",
    "Oracle username and/or password not valid" : "Nav derīga Oracle parole un/vai lietotājvārds",
    "PostgreSQL username and/or password not valid" : "Nav derīga PostgreSQL parole un/vai lietotājvārds",
    "Set an admin username." : "Iestatiet administratora lietotājvārdu.",
    "The username is already being used" : "Šāds lietotājvārds jau tiek izmantots",
    "A valid username must be provided" : "Jānorāda derīgs lietotājvārds",
    "User disabled" : "Lietotājs deaktivizēts"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> nextcloud-29.0.12.zip: nextcloud/lib/l10n/lv.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Nevar rakstīt \"config\" mapē!",
    "See %s" : "Skatīt %s",
    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "Lietotne %1$s nav pieejama vai tai ir ar šo serveri nesaderīga versija. Lūgums pārbaudīt lietotņu mapi.",
    "Sample configuration detected" : "Atrasta konfigurācijas paraugs",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Konstatēts, ka paraug konfigurācija ir nokopēta. Tas var izjaukt jūsu instalāciju un nav atbalstīts. Lūdzu, izlasiet dokumentāciju, pirms veicat izmaiņas config.php",
    "%s email verification" : "%s e-pasta pārbaude",
    "Email verification" : "E-pasta pārbaude",
    "Click the following button to confirm your email." : "Jāklikšķina zemā esošā poga, lai apstiprinātu savu e-pasta adresi.",
    "Confirm your email" : "Apstiprināt savu e-pasta adresi",
    "%1$s and %2$s" : "%1$s un %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s un %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s un %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s un %5$s",
    "PHP %s or higher is required." : "Ir nepieciešams PHP %s vai jaunāks.",
    "PHP with a version lower than %s is required." : "Ir nepieciešams PHP vecāks kā %s.",
    "%sbit or higher PHP required." : "Nepieciešams %sbit vai jaunāks PHP.",
    "The command line tool %s could not be found" : "Komandrindas rīku %s nevarēja atrast",
    "The library %s is not available." : "Bibliotēka %s nav pieejama.",
    "Server version %s or higher is required." : "Ir vajadzīga servera versija %s vai jaunāka.",
    "Server version %s or lower is required." : "Ir vajadzīga servera versija %s vai vecāka.",
    "Authentication" : "Autentifikācija",
    "Unknown filetype" : "Nezināms datnes veids",
    "Invalid image" : "Nederīgs attēls",
    "Avatar image is not square" : "Avatar attēls nav kvadrāts",
    "Files" : "Datnes",
    "View profile" : "Skatīt profilu",
    "today" : "šodien",
    "yesterday" : "vakar",
    "_%n day ago_::_%n days ago_" : ["%n dienas atpakaļ","%n dienas atpakaļ","%n dienām"],
    "last month" : "pagājušajā mēnesī",
    "_%n month ago_::_%n months ago_" : ["%n mēneši atpakaļ","%n mēneši atpakaļ","%n mēnešiem"],
    "last year" : "gājušajā gadā",
    "_%n year ago_::_%n years ago_" : ["%n gadiem","%n gadiem","%n gadiem"],
    "_%n hour ago_::_%n hours ago_" : ["%n stundas atpakaļ","%n stundas atpakaļ","%n stundām"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minūtes atpakaļ","%n minūtes atpakaļ","%n minūtēm"],
    "seconds ago" : "sekundēm",
    "File already exists" : "Datne jau pastāv",
    "Filename contains at least one invalid character" : "Datnes nosaukums satur vismaz vienu nederīgu rakstzīmi",
    "Empty filename is not allowed" : "Tukšs datnes nosaukums nav atļauts",
    "__language_name__" : "Latviešu",
    "Help & privacy" : "Palīdzība un privātums",
    "Appearance and accessibility" : "Izskats un piekļūstamība",
    "Apps" : "Lietotnes",
    "Personal settings" : "Personiskie iestatījumi",
    "Administration settings" : "Pārvaldīšanas iestatījumi",
    "Settings" : "Iestatījumi",
    "Log out" : "Izrakstīties",
    "Accounts" : "Konti",
    "Email" : "E-pasts",
    "Phone" : "Tālrunis",
    "Twitter" : "Twitter",
    "Website" : "Mājaslapa",
    "Address" : "Adrese",
    "Profile picture" : "Profila attēls",
    "About" : "Par",
    "Display name" : "Attēlojamais vārds",
    "Role" : "Loma",
    "Additional settings" : "Papildu iestatījumi",
    "Oracle connection could not be established" : "Nevar izveidot savienojumu ar Oracle",
    "Set an admin password." : "Iestatīt pārvaldītāja paroli.",
    "Unknown share type" : "Nezināms kopīgošanas veids",
    "You are not allowed to share %s" : "Tev nav ļauts dalīties ar %s",
    "Could not find category \"%s\"" : "Nevarēja atrast kategoriju “%s”",
    "Sunday" : "Svētdiena",
    "Monday" : "Pirmdiena",
    "Tuesday" : "Otrdiena",
    "Wednesday" : "Trešdiena",
    "Thursday" : "Ceturtdiena",
    "Friday" : "Piektdiena",
    "Saturday" : "Sestdiena",
    "Sun." : "Sv.",
    "Mon." : "Pr.",
    "Tue." : "Ot.",
    "Wed." : "Tr.",
    "Thu." : "Ce.",
    "Fri." : "Pk.",
    "Sat." : "Se.",
    "Su" : "Sv",
    "Mo" : "Pr",
    "Tu" : "Ot",
    "We" : "Tr",
    "Th" : "Ce",
    "Fr" : "Pi",
    "Sa" : "Se",
    "January" : "Janvāris",
    "February" : "Februāris",
    "March" : "Marts",
    "April" : "Aprīlis",
    "May" : "Maijs",
    "June" : "Jūnijs",
    "July" : "Jūlijs",
    "August" : "Augusts",
    "September" : "Septembris",
    "October" : "Oktobris",
    "November" : "Novembris",
    "December" : "Decembris",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Mai.",
    "Jun." : "Jūn.",
    "Jul." : "Jūl.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dec.",
    "A valid password must be provided" : "Jānorāda derīga parole",
    "Login canceled by app" : "Pieteikšanos atcelā lietotne",
    "a safe home for all your data" : "droša vieta visiem Taviem datiem",
    "Application is not enabled" : "Lietotne nav iespējota",
    "Authentication error" : "Autentifikācijas kļūda",
    "Token expired. Please reload page." : "Pilnvarai ir beidzies derīgums. Lūgums pārlādēt lapu.",
    "PHP module %s not installed." : "PHP modulis %s nav instalēts.",
    "Please ask your server administrator to install the module." : "Lūgums vaicāt savam servera pārvaldītāja, lai uzstāda moduli.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Tas ir iespējams, kešatmiņa / paātrinātājs, piemēram, Zend OPcache vai eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP modulis ir uzstādīts, taču tas joprojām ir uzskatāms kā trūkstošs, pazudis?",
    "Please ask your server administrator to restart the web server." : "Lūgums vaicāt savam servera pārvaldītājām pārsāknēt tīmekļa serveri.",
    "Storage unauthorized. %s" : "Krātuve neautorizēta. %s",
    "Storage incomplete configuration. %s" : "Storage incomplete configuration. %s",
    "Storage connection error. %s" : "Datu savienojuma kļūda. %s",
    "Storage is temporarily not available" : "Glabātuve īslaicīgi nav pieejama",
    "Storage connection timeout. %s" : "Datu savienojuma taimauts. %s",
    "Text" : "Teksts",
    "Summary" : "Kopsavilkums",
    "Translate" : "Tulkot",
    "File name is a reserved word" : "Datnes nosaukums ir aizņemts vārds",
    "File name is too long" : "Datnes nosaukums ir pārāk garš",
    "Users" : "Lietotāji",
    "Open »%s«" : "Atvērt »%s«",
    "File is currently busy, please try again later" : "Datne pašlaik ir aizņemta. Lūgums vēlāk mēģināt vēlreiz"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
